@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: membername.cpp,v 1.16 2001/03/19 19:27:41 root Exp $
+ * 
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -30,7 +30,7 @@ MemberName::~MemberName()
 {
 }
 
-int MemberName::compareItems(GCI item1, GCI item2)
+int MemberName::compareItems(QCollection::Item item1, QCollection::Item item2)
 {
   MemberDef *m1=(MemberDef *)item1;
   MemberDef *m2=(MemberDef *)item2;
@@ -39,9 +39,9 @@ int MemberName::compareItems(GCI item1, GCI item2)
   FileDef  *f1=m1->getFileDef();
   FileDef  *f2=m2->getFileDef();
   if (c1 && c2)
-    return strcmp(c1->name(),c2->name());
+    return qstrcmp(c1->name(),c2->name());
   else if (f1 && f2)
-    return strcmp(f1->name(),f2->name());
+    return qstrcmp(f1->name(),f2->name());
   else 
     return 0;
 }
@@ -52,7 +52,7 @@ MemberNameInfo::MemberNameInfo(const char *n) : QList<MemberInfo>()
   setAutoDelete(TRUE);
 }
 
-int MemberNameInfo::compareItems(GCI item1, GCI item2)
+int MemberNameInfo::compareItems(QCollection::Item item1, QCollection::Item item2)
 {
   MemberInfo *m1=(MemberInfo *)item1;
   MemberInfo *m2=(MemberInfo *)item2;
@@ -61,9 +61,9 @@ int MemberNameInfo::compareItems(GCI item1, GCI item2)
   FileDef  *f1=m1->memberDef->getFileDef();
   FileDef  *f2=m2->memberDef->getFileDef();
   if (c1 && c2)
-    return strcmp(c1->name(),c2->name());
+    return qstrcmp(c1->name(),c2->name());
   else if (f1 && f2)
-    return strcmp(f1->name(),f2->name());
+    return qstrcmp(f1->name(),f2->name());
   else 
     return 0;
 }
@@ -72,11 +72,11 @@ MemberNameIterator::MemberNameIterator(const MemberName &mnlist) :
 {
 }
 
-int MemberNameSDict::compareItems(GCI item1, GCI item2)
+int MemberNameSDict::compareItems(QCollection::Item item1, QCollection::Item item2)
 {
   MemberName *n1=(MemberName *)item1;
   MemberName *n2=(MemberName *)item2;
-  return stricmp(n1->memberName()+getPrefixIndex(n1->memberName()),
+  return qstricmp(n1->memberName()+getPrefixIndex(n1->memberName()),
                  n2->memberName()+getPrefixIndex(n2->memberName())
                 );
 }
